/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsITooltipTextProvi">
 **/

package org.mozilla.xpcom;

public interface nsITooltipTextProvider extends nsISupports
{
  public static final String NS_ITOOLTIPTEXTPROVIDER_IID =
    "{b128a1e6-44f3-4331-8fbe-5af360ff21ee}";

  public boolean getNodeText(nsIDOMNode arg1, String[] arg2);

}
